@@ -68,13 +68,12 @@ typedef enum
   STATE_BOXED_FIELD,
   STATE_STRUCT,
   STATE_STRUCT_FIELD,
-  STATE_ERRORDOMAIN, /* 25 */
-  STATE_UNION,
+  STATE_UNION,           /* 25 */
   STATE_UNION_FIELD,
   STATE_NAMESPACE_CONSTANT,
   STATE_CLASS_CONSTANT,
-  STATE_INTERFACE_CONSTANT,  /* 30 */
-  STATE_ALIAS,
+  STATE_INTERFACE_CONSTANT,
+  STATE_ALIAS,           /* 30 */
   STATE_TYPE,
   STATE_ATTRIBUTE,
   STATE_DOC,
@@ -806,6 +805,9 @@ start_function (GMarkupParseContext *context,
 	       strcmp (element_name, "method") == 0 ||
 	       strcmp (element_name, "callback") == 0);
       break;
+    case STATE_ENUM:
+      found = strcmp (element_name, "function") == 0;
+      break;
     case STATE_STRUCT_FIELD:
       found = (found || strcmp (element_name, "callback") == 0);
       break;
@@ -926,6 +928,15 @@ start_function (GMarkupParseContext *context,
 	  union_->members = g_list_append (union_->members, function);
 	}
 	break;
+      case G_IR_NODE_ENUM:
+      case G_IR_NODE_FLAGS:
+	{
+	  GIrNodeEnum *enum_;
+
+	  enum_ = (GIrNodeEnum *)CURRENT_NODE (ctx);
+	  enum_->methods = g_list_append (enum_->methods, function);
+	}
+	break;
       default:
 	g_assert_not_reached ();
       }
@@ -1333,6 +1344,7 @@ start_enum (GMarkupParseContext *context,
   const gchar *typename;
   const gchar *typeinit;
   const gchar *deprecated;
+  const gchar *error_domain;
   GIrNodeEnum *enum_;
 
   if (!((strcmp (element_name, "enumeration") == 0 && ctx->state == STATE_NAMESPACE) ||
@@ -1345,6 +1357,7 @@ start_enum (GMarkupParseContext *context,
   name = find_attribute ("name", attribute_names, attribute_values);
   typename = find_attribute ("glib:type-name", attribute_names, attribute_values);
   typeinit = find_attribute ("glib:get-type", attribute_names, attribute_values);
+  error_domain = find_attribute ("glib:error-domain", attribute_names, attribute_values);
   deprecated = find_attribute ("deprecated", attribute_names, attribute_values);
 
   if (name == NULL)
@@ -1362,6 +1375,8 @@ start_enum (GMarkupParseContext *context,
   ((GIrNode *)enum_)->name = g_strdup (name);
   enum_->gtype_name = g_strdup (typename);
   enum_->gtype_init = g_strdup (typeinit);
+  enum_->error_domain = g_strdup (error_domain);
+
   if (deprecated)
     enum_->deprecated = TRUE;
   else
@@ -1614,68 +1629,6 @@ start_constant (GMarkupParseContext *context,
   return TRUE;
 }
 
-static gboolean
-start_errordomain (GMarkupParseContext *context,
-		   const gchar         *element_name,
-		   const gchar        **attribute_names,
-		   const gchar        **attribute_values,
-		   ParseContext        *ctx,
-		   GError             **error)
-{
-  const gchar *name;
-  const gchar *getquark;
-  const gchar *codes;
-  const gchar *deprecated;
-  GIrNodeErrorDomain *domain;
-
-  if (!(strcmp (element_name, "errordomain") == 0 &&
-	ctx->state == STATE_NAMESPACE))
-    return FALSE;
-
-  if (!introspectable_prelude (context, attribute_names, attribute_values, ctx, STATE_ERRORDOMAIN))
-    return TRUE;
-
-
-  name = find_attribute ("name", attribute_names, attribute_values);
-  getquark = find_attribute ("get-quark", attribute_names, attribute_values);
-  codes = find_attribute ("codes", attribute_names, attribute_values);
-  deprecated = find_attribute ("deprecated", attribute_names, attribute_values);
-
-  if (name == NULL)
-    {
-      MISSING_ATTRIBUTE (context, error, element_name, "name");
-      return FALSE;
-    }
-  else if (getquark == NULL)
-    {
-      MISSING_ATTRIBUTE (context, error, element_name, "getquark");
-      return FALSE;
-    }
-  else if (codes == NULL)
-    {
-      MISSING_ATTRIBUTE (context, error, element_name, "codes");
-      return FALSE;
-    }
-
-  domain = (GIrNodeErrorDomain *) _g_ir_node_new (G_IR_NODE_ERROR_DOMAIN,
-						 ctx->current_module);
-
-  ((GIrNode *)domain)->name = g_strdup (name);
-  domain->getquark = g_strdup (getquark);
-  domain->codes = g_strdup (codes);
-
-  if (deprecated)
-    domain->deprecated = TRUE;
-  else
-    domain->deprecated = FALSE;
-
-  push_node (ctx, (GIrNode *) domain);
-  ctx->current_module->entries =
-    g_list_append (ctx->current_module->entries, domain);
-
-  return TRUE;
-}
-
 static gboolean
 start_interface (GMarkupParseContext *context,
 		 const gchar         *element_name,
@@ -1994,6 +1947,10 @@ start_type (GMarkupParseContext *context,
           const char *cp = ctype + strlen(ctype) - 1;
           while (cp > ctype && *cp-- == '*')
             pointer_depth++;
+
+	  if (g_str_has_prefix (ctype, "gpointer")
+	      || g_str_has_prefix (ctype, "gconstpointer"))
+	    pointer_depth++;
         }
 
       if (ctx->current_typed->type == G_IR_NODE_PARAM &&
@@ -2788,10 +2745,6 @@ start_element_handler (GMarkupParseContext *context,
 		      attribute_names, attribute_values,
 		      ctx, error))
 	goto out;
-      else if (start_errordomain (context, element_name,
-		      attribute_names, attribute_values,
-		      ctx, error))
-	goto out;
       break;
 
     case 'f':
@@ -3249,6 +3202,9 @@ end_element_handler (GMarkupParseContext *context,
 	      state_switch (ctx, STATE_STRUCT);
 	    else if (CURRENT_NODE (ctx)->type == G_IR_NODE_UNION)
 	      state_switch (ctx, STATE_UNION);
+	    else if (CURRENT_NODE (ctx)->type == G_IR_NODE_ENUM ||
+		     CURRENT_NODE (ctx)->type == G_IR_NODE_FLAGS)
+	      state_switch (ctx, STATE_ENUM);
 	    else
 	      {
 		int line_number, char_number;
@@ -3290,14 +3246,6 @@ end_element_handler (GMarkupParseContext *context,
 	}
       break;
 
-    case STATE_ERRORDOMAIN:
-      if (require_end_element (context, ctx, "errordomain", element_name, error))
-	{
-	  pop_node (ctx);
-	  state_switch (ctx, STATE_NAMESPACE);
-	}
-      break;
-
     case STATE_INTERFACE_PROPERTY:
       if (strcmp ("type", element_name) == 0)
 	break;
@@ -3327,6 +3275,8 @@ end_element_handler (GMarkupParseContext *context,
     case STATE_ENUM:
       if (strcmp ("member", element_name) == 0)
 	break;
+      else if (strcmp ("function", element_name) == 0)
+	break;
       else if (require_one_of_end_elements (context, ctx,
 					    element_name, error, "enumeration",
 					    "bitfield", NULL))
