@@ -111,11 +111,15 @@ void regress_test_ghash_nothing_in2 (GHashTable *in);
 GHashTable *regress_test_ghash_nested_everything_return (void);
 GHashTable *regress_test_ghash_nested_everything_return2 (void);
 
+/* GPtrArray */
+GPtrArray *regress_test_garray_container_return (void);
+
 /* error? */
 
 /* closure */
 int regress_test_closure (GClosure *closure);
 int regress_test_closure_one_arg (GClosure *closure, int arg);
+GVariant *regress_test_closure_variant (GClosure *closure, const GVariant* arg);
 
 /* value */
 int regress_test_int_value_arg(const GValue *v);
@@ -138,6 +142,8 @@ GVariant *regress_test_gvariant_as (void);
 
 /* enums / flags */
 
+#define NUM_REGRESS_FOO
+
 typedef enum
 {
   REGRESS_TEST_VALUE1,
@@ -237,6 +243,23 @@ struct _RegressTestStructD
   GPtrArray           *garray;
 };
 
+/* This one has an array of anonymous unions, inspired by GValue */
+struct RegressTestStructE
+{
+  GType some_type;
+  union {
+    gint	v_int;
+    guint	v_uint;
+    glong	v_long;
+    gulong	v_ulong;
+    gint64      v_int64;
+    guint64     v_uint64;
+    gfloat	v_float;
+    gdouble	v_double;
+    gpointer	v_pointer;
+  } some_union[2];
+};
+
 /* plain-old-data boxed types */
 typedef struct _RegressTestSimpleBoxedA RegressTestSimpleBoxedA;
 typedef struct _RegressTestSimpleBoxedB RegressTestSimpleBoxedB;
@@ -340,6 +363,8 @@ int        regress_test_obj_instance_method (RegressTestObj *obj);
 double     regress_test_obj_static_method (int x);
 void       regress_forced_method (RegressTestObj *obj);
 
+void regress_test_array_fixed_out_objects (RegressTestObj ***objs);
+
 void regress_test_obj_torture_signature_0 (RegressTestObj    *obj,
                                    int        x,
                                    double     *y,
@@ -607,6 +632,9 @@ GValue *regress_test_strv_in_gvalue (void);
 
 GObject * _regress_this_is_a_private_symbol (void);
 
+void regress_test_multiline_doc_comments (void);
+void regress_test_nested_parameter (int a);
+
 /**
  * RegressSkippedStructure: (skip)
  *
